# `py-semantic-taxonomy` Changelog

## [0.4.3] - 2025-06-07

* Fix packaging to include web media

## [0.4.2] - 2025-06-05

* [Fix #63: `typesense` implementation assumes only one running instance of PyST](https://github.com/cauldron/py-semantic-taxonomy/issues/63)

## [0.4.1] - 2025-05-07

* [Fix #60: `Association` serialization is excluding `extra` attributes](https://github.com/cauldron/py-semantic-taxonomy/issues/60)
* [Fix #61: `ConceptScheme` should have copyable IRI in sidebar](https://github.com/cauldron/py-semantic-taxonomy/issues/61)
* [Fix #62: Missing dark mode elements: History notes](https://github.com/cauldron/py-semantic-taxonomy/issues/62)

## [0.4.0] - 2025-05-06

* [#55: Indexed queries within JSONB elements](https://github.com/cauldron/py-semantic-taxonomy/pull/55)
* [#56: Make `pyst` more RESTful](https://github.com/cauldron/py-semantic-taxonomy/pull/56)
* [#57: Fix some missing dynamic background colors](https://github.com/cauldron/py-semantic-taxonomy/pull/57)
* [Fix #58: API Path for a `ConceptScheme` is missing slash](https://github.com/cauldron/py-semantic-taxonomy/issues/58)
* [Fix #59: Add status URL endpoint](https://github.com/cauldron/py-semantic-taxonomy/issues/59)

## [0.3.0] - 2025-04-30

* [#54: Language redo to persist language choice and make globally available](https://github.com/cauldron/py-semantic-taxonomy/pull/54)
* [#53: Hierarchy queries and info display](https://github.com/cauldron/py-semantic-taxonomy/pull/53)

## [0.2.0] - 2025-04-10

First complete release with web frontend

## [0.1.0] - 2025-03-20

Initial release
